### container

gguf-container frontend (gguf.us)

#### install it via:
```
pip install gguf-container
```
[<img src="https://raw.githubusercontent.com/calcuis/cgg/master/cgg.gif" width="128" height="128">](https://github.com/calcuis/cgg)
[<img src="https://raw.githubusercontent.com/calcuis/gguf-connector/master/gguf.gif" width="128" height="128">](https://github.com/calcuis/gguf-connector)
[<img src="https://raw.githubusercontent.com/calcuis/llama-core/master/lime.gif" width="128" height="128">](https://github.com/calcuis/llama-core)
[<img src="https://raw.githubusercontent.com/calcuis/gguf-core/master/gguf.gif" width="128" height="128">](https://github.com/calcuis/gguf-core)
[<img src="https://raw.githubusercontent.com/calcuis/chatgpt-model-selector/master/callgg.gif" width="128" height="128">](https://github.com/calcuis/callgg)
[<img src="https://raw.githubusercontent.com/calcuis/gguf-selector/master/selector.gif" width="128" height="128">](https://github.com/calcuis/gguf-selector)

#### launch to the container frontend by:
```
python -m gguf_container
```

find full source code in this pack; you can opt to run the server.py and host the frontend locally